#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailTip:
    def __init__(self):
        self.mailtipType = None
        self.value = None
        pass


class __MailTipSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailTip()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        mailtipTypeValue = value['mailtipType']
        instance.mailtipType = serder.STRING.parse(mailtipTypeValue)
        valueValue = value['value']
        instance.value = serder.STRING.parse(valueValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        mailtipTypeValue = value.mailtipType
        instance["mailtipType"] = serder.STRING.encode(mailtipTypeValue)
        valueValue = value.value
        instance["value"] = serder.STRING.encode(valueValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IInternalContainersByLocation_VERSION = "5.3.2861"


class IInternalContainersByLocation(BaseEndpoint):
    def __init__(self, apiKey, url, location):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/containers/{location}/_by_location'
        self.location_ = location
        self.base = self.base.replace('{location}', location)

    def listByType(self, query):
        postUri = "/list_by_type"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
        __data__ = __ContainerQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInternalContainersByLocation_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class CertInfo:
    def __init__(self):
        self.usage = None
        self.x509Certificate = None
        pass


class __CertInfoSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = CertInfo()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.CertInfoCertUsage import CertInfoCertUsage
        from netbluemind.addressbook.api.CertInfoCertUsage import __CertInfoCertUsageSerDer__
        usageValue = value['usage']
        instance.usage = serder.SetSerDer(
            __CertInfoCertUsageSerDer__()).parse(usageValue)
        x509CertificateValue = value['x509Certificate']
        instance.x509Certificate = serder.ByteArraySerDer.parse(
            x509CertificateValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.CertInfoCertUsage import CertInfoCertUsage
        from netbluemind.addressbook.api.CertInfoCertUsage import __CertInfoCertUsageSerDer__
        usageValue = value.usage
        instance["usage"] = serder.SetSerDer(
            __CertInfoCertUsageSerDer__()).encode(usageValue)
        x509CertificateValue = value.x509Certificate
        instance["x509Certificate"] = serder.ByteArraySerDer.encode(
            x509CertificateValue)
        return instance
